ReflectionShim (py4j-java 0.10.9.7 API)

Package py4j.reflection

## Class ReflectionShim

- java.lang.Object
- - py4j.reflection.ReflectionShim

-     public class ReflectionShim
      extends java.lang.Object

- - ### Constructor Summary

    Constructors
    Constructor | Description
    --- | ---
    `ReflectionShim()` |

  - ### Method Summary

    All Methods Static Methods Concrete Methods
    Modifier and Type | Method | Description
    --- | --- | ---
    `static boolean` | `trySetAccessible​(java.lang.reflect.AccessibleObject accessibleObject)` | If there is `trySetAccessible` method defined in `AccessibleObject`, it should be used; otherwise, fallback to `setAccessible`.

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Constructor Detail

    - #### ReflectionShim

          public ReflectionShim()

  - ### Method Detail

    - #### trySetAccessible

          public static boolean trySetAccessible​(java.lang.reflect.AccessibleObject accessibleObject)

      If there is `trySetAccessible` method defined in `AccessibleObject`, it should be used; otherwise, fallback to `setAccessible`.